@@ -10,7 +10,9 @@ class Development(object):
     ]
     COMMANDS = [
         "zemfrog.commands.api",
-        "zemfrog.commands.blueprint"
+        "zemfrog.commands.blueprint",
+        "zemfrog.commands.schema",
+        "zemfrog.commands.command"
     ]
     BLUEPRINTS = []
     APIS = []
